@@ -28,7 +28,8 @@
 
 #include "net.h"
 
-#include <QHostAddress>
+#include <QSslCertificate>
+#include <QSslKey>
 #include <QString>
 
 namespace Utils
@@ -63,7 +64,7 @@ namespace Utils
                     || (addr == QHostAddress(QLatin1String("::ffff:127.0.0.1")));
         }
 
-        bool isIPInRange(const QHostAddress &addr, const QList<Subnet> &subnets)
+        bool isIPInRange(const QHostAddress &addr, const QVector<Subnet> &subnets)
         {
             QHostAddress protocolEquivalentAddress;
             bool addrConversionOk = false;
@@ -89,5 +90,32 @@ namespace Utils
         {
             return subnet.first.toString() + '/' + QString::number(subnet.second);
         }
+
+        QList<QSslCertificate> loadSSLCertificate(const QByteArray &data)
+        {
+            const QList<QSslCertificate> certs {QSslCertificate::fromData(data)};
+            if (std::any_of(certs.cbegin(), certs.cend(), [](const QSslCertificate &c) { return c.isNull(); }))
+                return {};
+            return certs;
+        }
+
+        bool isSSLCertificatesValid(const QByteArray &data)
+        {
+            return !loadSSLCertificate(data).isEmpty();
+        }
+
+        QSslKey loadSSLKey(const QByteArray &data)
+        {
+            // try different formats
+            QSslKey key {data, QSsl::Rsa};
+            if (!key.isNull())
+                return key;
+            return {data, QSsl::Ec};
+        }
+
+        bool isSSLKeyValid(const QByteArray &data)
+        {
+            return !loadSSLKey(data).isNull();
+        }
     }
 }
