@@ -30,29 +30,23 @@
 #define PEERLISTWIDGET_H
 
 #include <QHash>
-#include <QPointer>
-#include <QSet>
-#include <QShortcut>
 #include <QTreeView>
 
-namespace Net
-{
-    class ReverseResolution;
-}
-
-class PeerListDelegate;
-class PeerListSortModel;
-class PropertiesWidget;
-
-class QSortFilterProxyModel;
 class QStandardItem;
 class QStandardItemModel;
 
+class PeerListSortModel;
+class PropertiesWidget;
+
 namespace BitTorrent
 {
     class TorrentHandle;
     class PeerInfo;
-    struct PeerAddress;
+}
+
+namespace Net
+{
+    class ReverseResolution;
 }
 
 class PeerListWidget : public QTreeView
@@ -63,9 +57,7 @@ public:
     explicit PeerListWidget(PropertiesWidget *parent);
     ~PeerListWidget() override;
 
-    void loadPeers(BitTorrent::TorrentHandle *const torrent, bool forceHostnameResolution = false);
-    QStandardItem *addPeer(const QString &ip, BitTorrent::TorrentHandle *const torrent, const BitTorrent::PeerInfo &peer);
-    void updatePeer(const QString &ip, BitTorrent::TorrentHandle *const torrent, const BitTorrent::PeerInfo &peer);
+    void loadPeers(const BitTorrent::TorrentHandle *torrent);
     void updatePeerHostNameResolutionState();
     void updatePeerCountryResolutionState();
     void clear();
@@ -81,18 +73,16 @@ private slots:
     void handleResolved(const QString &ip, const QString &hostname);
 
 private:
+    void updatePeer(const QString &ip, const BitTorrent::TorrentHandle *torrent, const BitTorrent::PeerInfo &peer, bool &isNewPeer);
+
     void wheelEvent(QWheelEvent *event) override;
 
-    QStandardItemModel *m_listModel;
-    PeerListDelegate *m_listDelegate;
-    PeerListSortModel *m_proxyModel;
+    QStandardItemModel *m_listModel = nullptr;
+    PeerListSortModel *m_proxyModel = nullptr;
+    PropertiesWidget *m_properties = nullptr;
+    Net::ReverseResolution *m_resolver = nullptr;
     QHash<QString, QStandardItem *> m_peerItems;
-    QHash<QString, BitTorrent::PeerAddress> m_peerAddresses;
-    QSet<QString> m_missingFlags;
-    QPointer<Net::ReverseResolution> m_resolver;
-    PropertiesWidget *m_properties;
     bool m_resolveCountries;
-    QShortcut *m_copyHotkey;
 };
 
 #endif // PEERLISTWIDGET_H
