@@ -34,6 +34,7 @@
 
 class QCheckBox;
 class QResizeEvent;
+
 class TransferListWidget;
 
 namespace BitTorrent
@@ -42,9 +43,15 @@ namespace BitTorrent
     class TrackerEntry;
 }
 
+namespace Net
+{
+    struct DownloadResult;
+}
+
 class BaseFilterWidget : public QListWidget
 {
     Q_OBJECT
+    Q_DISABLE_COPY(BaseFilterWidget)
 
 public:
     BaseFilterWidget(QWidget *parent, TransferListWidget *transferList);
@@ -59,7 +66,7 @@ protected:
     TransferListWidget *transferList;
 
 private slots:
-    virtual void showMenu(QPoint) = 0;
+    virtual void showMenu(const QPoint &) = 0;
     virtual void applyFilter(int row) = 0;
     virtual void handleNewTorrent(BitTorrent::TorrentHandle *const) = 0;
     virtual void torrentAboutToBeDeleted(BitTorrent::TorrentHandle *const) = 0;
@@ -68,6 +75,7 @@ private slots:
 class StatusFilterWidget : public BaseFilterWidget
 {
     Q_OBJECT
+    Q_DISABLE_COPY(StatusFilterWidget)
 
 public:
     StatusFilterWidget(QWidget *parent, TransferListWidget *transferList);
@@ -79,7 +87,7 @@ private slots:
 private:
     // These 4 methods are virtual slots in the base class.
     // No need to redeclare them here as slots.
-    void showMenu(QPoint) override;
+    void showMenu(const QPoint &) override;
     void applyFilter(int row) override;
     void handleNewTorrent(BitTorrent::TorrentHandle *const) override;
     void torrentAboutToBeDeleted(BitTorrent::TorrentHandle *const) override;
@@ -88,6 +96,7 @@ private:
 class TrackerFiltersList : public BaseFilterWidget
 {
     Q_OBJECT
+    Q_DISABLE_COPY(TrackerFiltersList)
 
 public:
     TrackerFiltersList(QWidget *parent, TransferListWidget *transferList, bool downloadFavicon);
@@ -105,13 +114,12 @@ public slots:
     void trackerWarning(const QString &hash, const QString &tracker);
 
 private slots:
-    void handleFavicoDownload(const QString &url, const QString &filePath);
-    void handleFavicoFailure(const QString &url, const QString &error);
+    void handleFavicoDownloadFinished(const Net::DownloadResult &result);
 
 private:
     // These 4 methods are virtual slots in the base class.
     // No need to redeclare them here as slots.
-    void showMenu(QPoint) override;
+    void showMenu(const QPoint &) override;
     void applyFilter(int row) override;
     void handleNewTorrent(BitTorrent::TorrentHandle *const torrent) override;
     void torrentAboutToBeDeleted(BitTorrent::TorrentHandle *const torrent) override;
@@ -141,8 +149,8 @@ public:
     void setDownloadTrackerFavicon(bool value);
 
 public slots:
-    void addTrackers(BitTorrent::TorrentHandle *const torrent, const QList<BitTorrent::TrackerEntry> &trackers);
-    void removeTrackers(BitTorrent::TorrentHandle *const torrent, const QList<BitTorrent::TrackerEntry> &trackers);
+    void addTrackers(BitTorrent::TorrentHandle *const torrent, const QVector<BitTorrent::TrackerEntry> &trackers);
+    void removeTrackers(BitTorrent::TorrentHandle *const torrent, const QVector<BitTorrent::TrackerEntry> &trackers);
     void changeTrackerless(BitTorrent::TorrentHandle *const torrent, bool trackerless);
     void trackerSuccess(BitTorrent::TorrentHandle *const torrent, const QString &tracker);
     void trackerWarning(BitTorrent::TorrentHandle *const torrent, const QString &tracker);
