@@ -29,10 +29,11 @@
 #pragma once
 
 #include <QHash>
-#include <QString>
 
 #include "apicontroller.h"
 
+class QString;
+
 class AuthController : public APIController
 {
     Q_OBJECT
