@@ -5,7 +5,7 @@
     <name>AboutDlg</name>
     <message>
         <source>About</source>
-        <translation>Om</translation>
+        <translation type="vanished">Om</translation>
     </message>
 </context>
 <context>
@@ -145,7 +145,7 @@
     </message>
     <message>
         <source>Seeding time limit must be between 0 and 525600 minutes.</source>
-        <translation>Distribuerings tidsgränsen måste vara mellan 0 och 525600 minuter.</translation>
+        <translation>Distributions tidsgränsen måste vara mellan 0 och 525600 minuter.</translation>
     </message>
     <message>
         <source>The port used for incoming connections must be between 1 and 65535.</source>
@@ -298,7 +298,7 @@
     </message>
     <message>
         <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
-        <translation>Ogiltigt kategorinamn:\nAnvänd inga specialtecken i kategorinamnet.</translation>
+        <translation>Ogiltigt kategorinamn:\nVänligen använd inga specialtecken i kategorinamnet.</translation>
     </message>
     <message>
         <source>Unable to create category</source>
@@ -332,9 +332,21 @@
         <source>qBittorrent has been shutdown</source>
         <translation>qBittorrent har stängts av</translation>
     </message>
+    <message>
+        <source>Open documentation</source>
+        <translation>Öppna dokumentationen</translation>
+    </message>
+    <message>
+        <source>Register to handle magnet links...</source>
+        <translation>Registrera för att hantera magnetlänkar...</translation>
+    </message>
+    <message>
+        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
+        <translation>Det går inte att lägga till noder. Vänligen se till att du följer formatet IP:port.</translation>
+    </message>
     <message>
         <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
-        <translation type="unfinished" />
+        <translation>JavaScript Krävs! Du måste aktivera JavaScript för att webbgränssnittet ska fungera korrekt</translation>
     </message>
 </context>
 <context>
@@ -367,22 +379,6 @@
         <source>Resume</source>
         <translation>Återuppta</translation>
     </message>
-    <message>
-        <source>Minimum Priority</source>
-        <translation>Lägsta prioritet</translation>
-    </message>
-    <message>
-        <source>Top Priority</source>
-        <translation>Högsta prioritet</translation>
-    </message>
-    <message>
-        <source>Decrease Priority</source>
-        <translation>Minska prioritet</translation>
-    </message>
-    <message>
-        <source>Increase Priority</source>
-        <translation>Höja prioritet</translation>
-    </message>
     <message>
         <source>Top Toolbar</source>
         <translation>Översta verktygsfältet</translation>
@@ -480,6 +476,38 @@
         <source>Transfers</source>
         <translation>Överföringar</translation>
     </message>
+    <message>
+        <source>Move up in the queue</source>
+        <translation>Flytta fram i kön</translation>
+    </message>
+    <message>
+        <source>Move Up Queue</source>
+        <translation>Flytta fram i kön</translation>
+    </message>
+    <message>
+        <source>Bottom of Queue</source>
+        <translation>Längst bak i kön</translation>
+    </message>
+    <message>
+        <source>Move to the bottom of the queue</source>
+        <translation>Flytta till slutet av kön</translation>
+    </message>
+    <message>
+        <source>Top of Queue</source>
+        <translation>Längst fram i kön</translation>
+    </message>
+    <message>
+        <source>Move Down Queue</source>
+        <translation>Flytta bak i kön</translation>
+    </message>
+    <message>
+        <source>Move down in the queue</source>
+        <translation>Flytta bak i kön</translation>
+    </message>
+    <message>
+        <source>Move to the top of the queue</source>
+        <translation>Flytta till början av kön</translation>
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -535,10 +563,6 @@
         <source>Torrent Queueing</source>
         <translation>Torrentkö</translation>
     </message>
-    <message>
-        <source>Seed torrents until their seeding time reaches</source>
-        <translation>Distribuera torrenter till deras distribueringstid når</translation>
-    </message>
     <message>
         <source>Automatically add these trackers to new downloads:</source>
         <translation>Lägg a&amp;utomatiskt till dessa bevakare till nya hämtningar:</translation>
@@ -581,7 +605,7 @@
     </message>
     <message>
         <source>Copy .torrent files for finished downloads to:</source>
-        <translation>Kopiera .torrent-filer för färdiga hämtningar till:</translation>
+        <translation>Kopiera .torrent-filer för slutförda hämtningar till:</translation>
     </message>
     <message>
         <source>Pre-allocate disk space for all files</source>
@@ -695,10 +719,6 @@
         <source>Use proxy for peer connections</source>
         <translation>Använd proxy för nodanslutningar</translation>
     </message>
-    <message>
-        <source>Disable connections not supported by proxies</source>
-        <translation>Inaktivera anslutningar som inte stöds av proxyer</translation>
-    </message>
     <message>
         <source>Use proxy only for torrents</source>
         <translation>Använd proxy endast för torrenter</translation>
@@ -709,7 +729,7 @@
     </message>
     <message>
         <source>Manually banned IP addresses...</source>
-        <translation>Manuellt bannlysta IP-adresser...</translation>
+        <translation>Manuellt förbjudna IP-adresser...</translation>
     </message>
     <message>
         <source>Apply to trackers</source>
@@ -789,10 +809,6 @@
         <source>Encryption mode:</source>
         <translation>Krypteringsläge:</translation>
     </message>
-    <message>
-        <source>Prefer encryption</source>
-        <translation>Föredra kryptering</translation>
-    </message>
     <message>
         <source>Require encryption</source>
         <translation>Kräv kryptering</translation>
@@ -821,26 +837,10 @@
         <source>Do not count slow torrents in these limits</source>
         <translation>Räkna inte med långsamma torrenter i dessa begränsningar</translation>
     </message>
-    <message>
-        <source>Share Ratio Limiting</source>
-        <translation>Delningsförhållandegräns</translation>
-    </message>
-    <message>
-        <source>Seed torrents until their ratio reaches</source>
-        <translation>Distribuera torrentfiler till deras förhållande når</translation>
-    </message>
     <message>
         <source>then</source>
         <translation>sedan</translation>
     </message>
-    <message>
-        <source>Pause them</source>
-        <translation>Pausa dem</translation>
-    </message>
-    <message>
-        <source>Remove them</source>
-        <translation>Ta bort dem</translation>
-    </message>
     <message>
         <source>Use UPnP / NAT-PMP to forward the port from my router</source>
         <translation>Använd UPnP / NAT-PMP för att vidarebefordra porten från min router</translation>
@@ -873,17 +873,13 @@
         <source>%L: Category</source>
         <translation>%L: Kategori</translation>
     </message>
-    <message>
-        <source>%G: Tags (seperated by comma)</source>
-        <translation type="vanished">%G: Taggar (separerade med kommatecken)</translation>
-    </message>
     <message>
         <source>%F: Content path (same as root path for multifile torrent)</source>
         <translation>%F: Innehållssökväg (samma som root-sökväg för flerfilig torrent)</translation>
     </message>
     <message>
         <source>%R: Root path (first torrent subdirectory path)</source>
-        <translation>%R: Root-sökväg (första torrentunderkatalogssökväg)</translation>
+        <translation>%R: Root-sökväg (första torrentundermappsökväg)</translation>
     </message>
     <message>
         <source>%D: Save path</source>
@@ -1041,10 +1037,234 @@
         <source>When adding a torrent</source>
         <translation>När en torrent läggs till</translation>
     </message>
+    <message>
+        <source>Info: The password is saved unencrypted</source>
+        <translation>Info: Lösenordet sparas okrypterat</translation>
+    </message>
+    <message>
+        <source>Strict super seeding:</source>
+        <translation>Strikt superdistribuering:</translation>
+    </message>
+    <message>
+        <source>μTP-TCP mixed mode algorithm:</source>
+        <translation>µTP-TCP blandad lägesalgoritm:</translation>
+    </message>
+    <message>
+        <source>Upload rate based</source>
+        <translation>Sändning betygbaserad</translation>
+    </message>
     <message>
         <source>%G: Tags (separated by comma)</source>
+        <translation>%G: Taggar (separerade med kommatecken)</translation>
+    </message>
+    <message>
+        <source>Socket backlog size:</source>
+        <translation>Uttagets bakloggsstorlek:</translation>
+    </message>
+    <message>
+        <source>Enable super seeding for torrent</source>
+        <translation>Aktivera superdistribuering för torrent</translation>
+    </message>
+    <message>
+        <source>Prefer TCP</source>
+        <translation>Föredra TCP</translation>
+    </message>
+    <message>
+        <source>Outstanding memory when checking torrents:</source>
+        <translation>Enastående minne när du kontrollerar torrenter:</translation>
+    </message>
+    <message>
+        <source>Anti-leech</source>
+        <translation>Anti-reciprokör</translation>
+    </message>
+    <message>
+        <source>Enable OS cache:</source>
+        <translation>Aktivera OS-cache</translation>
+    </message>
+    <message>
+        <source>When ratio reaches</source>
+        <translation>När förhållandet når</translation>
+    </message>
+    <message>
+        <source>sec</source>
+        <translation>sek</translation>
+    </message>
+    <message>
+        <source>When seeding time reaches</source>
+        <translation>När distribueringstiden når</translation>
+    </message>
+    <message>
+        <source>Allow multiple connections from the same IP address:</source>
+        <translation>Tillåt flera anslutningar från samma IP-adress</translation>
+    </message>
+    <message>
+        <source>File pool size:</source>
+        <translation>Filpool storlek</translation>
+    </message>
+    <message>
+        <source>Any interface</source>
+        <translation>Alla gränssnitt</translation>
+    </message>
+    <message>
+        <source>Always announce to all tiers:</source>
+        <translation>Meddela alltid till alla nivåer:</translation>
+    </message>
+    <message>
+        <source>Embedded tracker port:</source>
+        <translation>Port för inbäddad bevakare:</translation>
+    </message>
+    <message>
+        <source>Optional IP Address to bind to (requires restart):</source>
+        <translation>Valfri IP-adress att binda till (kräver omstart):</translation>
+    </message>
+    <message>
+        <source>Fastest upload</source>
+        <translation>Snabbaste sändning</translation>
+    </message>
+    <message>
+        <source>Pause torrent</source>
+        <translation>Pausa torrent</translation>
+    </message>
+    <message>
+        <source>Remove torrent and its files</source>
+        <translation>Ta bort torrent och dess filer</translation>
+    </message>
+    <message>
+        <source>qBittorrent Section</source>
+        <translation>qBittorrent-avsnitt</translation>
+    </message>
+    <message>
+        <source>Send buffer watermark factor:</source>
+        <translation>Skicka buffert vattenstämpelsfaktor:</translation>
+    </message>
+    <message>
+        <source>libtorrent Section</source>
+        <translation>libtorrent-avsnitt</translation>
+    </message>
+    <message>
+        <source>Coalesce reads &amp; writes:</source>
+        <translation>Koalition läsningar &amp; skrivningar:</translation>
+    </message>
+    <message>
+        <source>Outgoing ports (Min) [0: Disabled]:</source>
+        <translation>Utgående portar (min) [0: Inaktiverat]:</translation>
+    </message>
+    <message>
+        <source>IP Address to report to trackers (requires restart):</source>
+        <translation>IP-adress att rapportera till bevakare (kräver omstart):</translation>
+    </message>
+    <message>
+        <source>Recheck torrents on completion:</source>
+        <translation>Kontrollera torrenter när de slutförs:</translation>
+    </message>
+    <message>
+        <source>Allow encryption</source>
+        <translation>Tillåt kryptering</translation>
+    </message>
+    <message>
+        <source>Send upload piece suggestions:</source>
+        <translation>Skicka förslag på sändningsdelar:</translation>
+    </message>
+    <message>
+        <source>Disk cache:</source>
+        <translation>Diskcache:</translation>
+    </message>
+    <message>
+        <source>Enable embedded tracker:</source>
+        <translation>Aktivera inbäddad bevakare:</translation>
+    </message>
+    <message>
+        <source>Remove torrent</source>
+        <translation>Ta bort torrent</translation>
+    </message>
+    <message>
+        <source>Outgoing ports (Max) [0: Disabled]:</source>
+        <translation>Utgående portar (max) [0: Inaktiverat]</translation>
+    </message>
+    <message>
+        <source>Asynchronous I/O threads:</source>
+        <translation>Asynkrona in/ut-trådar:</translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation>s</translation>
+    </message>
+    <message>
+        <source>Send buffer watermark:</source>
+        <translation>Skicka buffert vattenstämpel:</translation>
+    </message>
+    <message>
+        <source>Disk cache expiry interval:</source>
+        <translation>Intervall för diskcache utgångsdatum:</translation>
+    </message>
+    <message>
+        <source>Peer proportional (throttles TCP)</source>
+        <translation>Proportionell nod (stryper TCP)</translation>
+    </message>
+    <message>
+        <source>Fixed slots</source>
+        <translation>Fasta platser</translation>
+    </message>
+    <message>
+        <source>Resolve peer countries (GeoIP):</source>
+        <translation>Slå upp nodernas länder (GeoIP)</translation>
+    </message>
+    <message>
+        <source>Advanced</source>
+        <translation>Avancerat</translation>
+    </message>
+    <message>
+        <source>min</source>
+        <translation>min</translation>
+    </message>
+    <message>
+        <source>Upload choking algorithm:</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Seeding Limits</source>
+        <translation>Distributionsgränser</translation>
+    </message>
+    <message>
+        <source>KiB</source>
+        <translation>KiB</translation>
+    </message>
+    <message>
+        <source>Round-robin</source>
+        <translation>Round Robin</translation>
+    </message>
+    <message>
+        <source>Upload slots behavior:</source>
+        <translation>Beteende för sändningsplatser</translation>
+    </message>
+    <message>
+        <source>Network Interface (requires restart):</source>
+        <translation>Nätverksgränssnitt (kräver omstart):</translation>
+    </message>
+    <message>
+        <source>MiB</source>
+        <translation>MiB</translation>
+    </message>
+    <message>
+        <source>Send buffer low watermark:</source>
+        <translation>Skicka buffert låg vattenstämpel:</translation>
+    </message>
+    <message>
+        <source>Save resume data interval:</source>
+        <translation>Intervall för att spara återupptagningsdata:</translation>
+    </message>
+    <message>
+        <source>Always announce to all trackers in a tier:</source>
+        <translation>Meddela alltid till alla bevakare i en nivå:</translation>
+    </message>
+    <message>
+        <source>Session timeout:</source>
+        <translation>Sessionen löpte ut:</translation>
+    </message>
+    <message>
+        <source>Listen on IPv6 address (requires restart):</source>
+        <translation>Lyssna på IPv6-adress (kräver omstart):</translation>
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
@@ -1108,6 +1328,22 @@
         <source>Country</source>
         <translation>Land</translation>
     </message>
+    <message>
+        <source>Ban peer permanently</source>
+        <translation>Förbjud noden permanent</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently ban the selected peers?</source>
+        <translation>Är du säker på att du vill permanent förbjuda de valda noderna?</translation>
+    </message>
+    <message>
+        <source>Copy IP:port</source>
+        <translation>Kopiera IP:port</translation>
+    </message>
+    <message>
+        <source>Add a new peer...</source>
+        <translation>Lägg till en ny nod...</translation>
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1126,6 +1362,14 @@
         <comment>Maximum (priority)</comment>
         <translation>Maximal</translation>
     </message>
+    <message>
+        <source>Mixed</source>
+        <translation>Blandat</translation>
+    </message>
+    <message>
+        <source>Do not download</source>
+        <translation>Hämta inte</translation>
+    </message>
 </context>
 <context>
     <name>PropTabBar</name>
@@ -1167,7 +1411,7 @@
     </message>
     <message>
         <source>ETA:</source>
-        <translation>Färdig om:</translation>
+        <translation>Slutförd om:</translation>
     </message>
     <message>
         <source>Uploaded:</source>
@@ -1293,6 +1537,14 @@
         <source>Upload limit:</source>
         <translation>Sändningsgräns:</translation>
     </message>
+    <message>
+        <source>Priority</source>
+        <translation>Prioritet</translation>
+    </message>
+    <message>
+        <source>Filter files...</source>
+        <translation>Filtrera filer...</translation>
+    </message>
 </context>
 <context>
     <name>ScanFoldersModel</name>
@@ -1372,7 +1624,7 @@
     </message>
     <message>
         <source>Queued I/O jobs:</source>
-        <translation>Köade I/O-jobb: </translation>
+        <translation>Köade in/ut-jobb: </translation>
     </message>
     <message>
         <source>Write cache overload:</source>
@@ -1411,7 +1663,7 @@
     </message>
     <message>
         <source>Completed (0)</source>
-        <translation>Färdiga (0)</translation>
+        <translation>Slutförda (0)</translation>
     </message>
     <message>
         <source>Resumed (0)</source>
@@ -1431,7 +1683,7 @@
     </message>
     <message>
         <source>Errored (0)</source>
-        <translation>Fallerade (0)</translation>
+        <translation>Fallerande (0)</translation>
     </message>
     <message>
         <source>All (%1)</source>
@@ -1447,7 +1699,7 @@
     </message>
     <message>
         <source>Completed (%1)</source>
-        <translation>Färdiga (%1)</translation>
+        <translation>Slutförda (%1)</translation>
     </message>
     <message>
         <source>Paused (%1)</source>
@@ -1467,36 +1719,12 @@
     </message>
     <message>
         <source>Errored (%1)</source>
-        <translation>Fallerade (%1)</translation>
+        <translation>Fallerande (%1)</translation>
     </message>
 </context>
 <context>
     <name>TorrentContentModel</name>
-    <message>
-        <source>Name</source>
-        <translation>Namn</translation>
-    </message>
-    <message>
-        <source>Size</source>
-        <translation>Storlek</translation>
-    </message>
-    <message>
-        <source>Progress</source>
-        <translation>Förlopp</translation>
-    </message>
-    <message>
-        <source>Download Priority</source>
-        <translation>Hämtningsprioritet</translation>
-    </message>
-    <message>
-        <source>Remaining</source>
-        <translation>Återstår</translation>
-    </message>
-    <message>
-        <source>Availability</source>
-        <translation>Tillgänglighet</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransferListModel</name>
     <message>
@@ -1619,7 +1847,7 @@
     <message>
         <source>Completed</source>
         <comment>Amount of data completed (e.g. in MB)</comment>
-        <translation>Färdig</translation>
+        <translation>Slutförd</translation>
     </message>
     <message>
         <source>Ratio Limit</source>
@@ -1641,6 +1869,10 @@
         <comment>i.e. Size including unwanted data</comment>
         <translation>Storlek totalt</translation>
     </message>
+    <message>
+        <source>Availability</source>
+        <translation>Tillgänglighet</translation>
+    </message>
 </context>
 <context>
     <name>TrackerListWidget</name>
@@ -1684,10 +1916,6 @@
         <source>Not contacted yet</source>
         <translation>Inte ännu kontaktad</translation>
     </message>
-    <message>
-        <source>#</source>
-        <translation>#</translation>
-    </message>
     <message>
         <source>N/A</source>
         <translation>Inga</translation>
@@ -1724,6 +1952,34 @@
         <source>Remove tracker</source>
         <translation>Ta bort bevakare</translation>
     </message>
+    <message>
+        <source>Remaining</source>
+        <translation>Återstår</translation>
+    </message>
+    <message>
+        <source>Availability</source>
+        <translation>Tillgänglighet</translation>
+    </message>
+    <message>
+        <source>Tier</source>
+        <translation>Nivå</translation>
+    </message>
+    <message>
+        <source>Download Priority</source>
+        <translation>Hämtningsprioritet</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Namn</translation>
+    </message>
+    <message>
+        <source>Progress</source>
+        <translation>Förlopp</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Storlek</translation>
+    </message>
 </context>
 <context>
     <name>TrackersAdditionDialog</name>
@@ -1761,7 +2017,7 @@
     </message>
     <message>
         <source>[F] Seeding</source>
-        <translation>[F] Distribuerar</translation>
+        <translation>[T] Distribuerar</translation>
     </message>
     <message>
         <source>Seeding</source>
@@ -1777,7 +2033,7 @@
     </message>
     <message>
         <source>[F] Downloading</source>
-        <translation>[F] Hämtar</translation>
+        <translation>[T] Hämtar</translation>
     </message>
     <message>
         <source>Downloading metadata</source>
@@ -1818,6 +2074,10 @@
         <source>Categories</source>
         <translation>Kategorier</translation>
     </message>
+    <message>
+        <source>Tags</source>
+        <translation>Taggar</translation>
+    </message>
 </context>
 <context>
     <name>TransferListWidget</name>
@@ -1841,7 +2101,7 @@
     <message>
         <source>Force Resume</source>
         <comment>Force Resume/start the torrent</comment>
-        <translation>Tvinga återupptagning</translation>
+        <translation>Tvinga återuppta</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -1889,14 +2149,6 @@
         <source>Set location...</source>
         <translation>Ange plats...</translation>
     </message>
-    <message>
-        <source>Copy name</source>
-        <translation>Kopiera namn</translation>
-    </message>
-    <message>
-        <source>Copy hash</source>
-        <translation>Kopiera hash</translation>
-    </message>
     <message>
         <source>Download first and last pieces first</source>
         <translation>Hämta första och sista delarna först</translation>
@@ -1919,18 +2171,10 @@
         <comment>Reset category</comment>
         <translation>Återställ</translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Prioritet</translation>
-    </message>
     <message>
         <source>Force recheck</source>
         <translation>Tvinga återkontroll</translation>
     </message>
-    <message>
-        <source>Copy magnet link</source>
-        <translation>Kopiera magnetlänk</translation>
-    </message>
     <message>
         <source>Super seeding mode</source>
         <translation>Superdistributionsläge</translation>
@@ -1965,7 +2209,7 @@
     </message>
     <message>
         <source>Force reannounce</source>
-        <translation>Tvinga återannonsering</translation>
+        <translation>Tvinga återannonsera</translation>
     </message>
     <message>
         <source>Edit Category</source>
@@ -1975,6 +2219,46 @@
         <source>Save path</source>
         <translation>Sökväg för att spara</translation>
     </message>
+    <message>
+        <source>Comma-separated tags:</source>
+        <translation>Kommaseparerade taggar:</translation>
+    </message>
+    <message>
+        <source>Add Tags</source>
+        <translation>Lägg till taggar</translation>
+    </message>
+    <message>
+        <source>Tags</source>
+        <translation>Taggar</translation>
+    </message>
+    <message>
+        <source>Magnet link</source>
+        <translation>Magnetlänk</translation>
+    </message>
+    <message>
+        <source>Hash</source>
+        <translation>Hash</translation>
+    </message>
+    <message>
+        <source>Remove All</source>
+        <translation>Ta bort alla</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Namn</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation>Kopiera</translation>
+    </message>
+    <message>
+        <source>Queue</source>
+        <translation>Kö</translation>
+    </message>
+    <message>
+        <source>Add...</source>
+        <translation>Lägg till...</translation>
+    </message>
 </context>
 <context>
     <name>UpDownRatioDialog</name>
@@ -2005,23 +2289,7 @@
 </context>
 <context>
     <name>about</name>
-    <message>
-        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
-        <translation>En avancerad BitTorrent-klient programmerad i C++, baserad på Qt-verktygslåda och libtorrent-rasterbar.</translation>
-    </message>
-    <message>
-        <source>Home Page:</source>
-        <translation>Hemsida:</translation>
-    </message>
-    <message>
-        <source>Forum:</source>
-        <translation>Forum:</translation>
-    </message>
-    <message>
-        <source>Bug Tracker:</source>
-        <translation>Felhantering:</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>confirmDeletionDlg</name>
     <message>
@@ -2184,22 +2452,10 @@
         <source>Search in:</source>
         <translation>Sök i:</translation>
     </message>
-    <message>
-        <source>Copy description page URL</source>
-        <translation>Kopiera beskrivningssidans webbadress</translation>
-    </message>
-    <message>
-        <source>Go to description page</source>
-        <translation>Gå till beskrivningssidan</translation>
-    </message>
     <message>
         <source>Results (showing</source>
         <translation>Resultat (visar</translation>
     </message>
-    <message>
-        <source>Download</source>
-        <translation>Hämta</translation>
-    </message>
     <message>
         <source>Filter</source>
         <translation>Filter</translation>
@@ -2233,7 +2489,7 @@
     </message>
     <message>
         <source>You can get new search engine plugins here:</source>
-        <translation>Du kan få nya sökmotorinsticksmoduler här:</translation>
+        <translation>Du kan skaffa nya sökmotorinsticksmoduler här:</translation>
     </message>
     <message>
         <source>Close</source>
@@ -2302,4 +2558,182 @@
         <translation>Version</translation>
     </message>
 </context>
+<context>
+    <name>PeersAdditionDialog</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <source>Add Peers</source>
+        <translation>Lägg till noder</translation>
+    </message>
+    <message>
+        <source>List of peers to add (one IP per line):</source>
+        <translation>Lista över noder att lägga till (en IP per rad):</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Format: IPv4:port / [IPv6]:port</source>
+        <translation>Format: IPv4:port / [IPv6]:port</translation>
+    </message>
+</context>
+<context>
+    <name>TagFilterWidget</name>
+    <message>
+        <source>New Tag</source>
+        <translation>Ny tagg</translation>
+    </message>
+    <message>
+        <source>Add tag...</source>
+        <translation>Lägg till tagg...</translation>
+    </message>
+    <message>
+        <source>Delete torrents</source>
+        <translation>Ta bort torrenter</translation>
+    </message>
+    <message>
+        <source>Tag:</source>
+        <translation>Tagg:</translation>
+    </message>
+    <message>
+        <source>Pause torrents</source>
+        <translation>Pausa torrenter</translation>
+    </message>
+    <message>
+        <source>Resume torrents</source>
+        <translation>Återuppta torrenter</translation>
+    </message>
+    <message>
+        <source>Remove unused tags</source>
+        <translation>Ta bort oanvända taggar</translation>
+    </message>
+    <message>
+        <source>Invalid tag name</source>
+        <translation>Ogiltigt taggnamn</translation>
+    </message>
+    <message>
+        <source>Remove tag</source>
+        <translation>Ta bort tagg</translation>
+    </message>
+</context>
+<context>
+    <name>TagFilterModel</name>
+    <message>
+        <source>All</source>
+        <translation>Alla</translation>
+    </message>
+    <message>
+        <source>Untagged</source>
+        <translation>Otaggade</translation>
+    </message>
+</context>
+<context>
+    <name>AboutDialog</name>
+    <message>
+        <source>Bug Tracker:</source>
+        <translation>Ärendehantering:</translation>
+    </message>
+    <message>
+        <source>About</source>
+        <translation>Om</translation>
+    </message>
+    <message>
+        <source>Forum:</source>
+        <translation>Forum:</translation>
+    </message>
+    <message>
+        <source>E-mail:</source>
+        <translation>E-post:</translation>
+    </message>
+    <message>
+        <source>Current maintainer</source>
+        <translation>Nuvarande utvecklare</translation>
+    </message>
+    <message>
+        <source>Home Page:</source>
+        <translation>Webbplats:</translation>
+    </message>
+    <message>
+        <source>Greece</source>
+        <translation>Grekland</translation>
+    </message>
+    <message>
+        <source>Special Thanks</source>
+        <translation>Särskilda tack</translation>
+    </message>
+    <message>
+        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
+        <translation>En avancerad BitTorrent-klient programmerad i C++, baserad på Qt-verktygslåda och libtorrent-rasterbar.</translation>
+    </message>
+    <message>
+        <source>Name:</source>
+        <translation>Namn:</translation>
+    </message>
+    <message>
+        <source>About qBittorrent</source>
+        <translation>Om qBittorrent</translation>
+    </message>
+    <message>
+        <source>Libraries</source>
+        <translation>Bibliotek</translation>
+    </message>
+    <message>
+        <source>License</source>
+        <translation>Licens</translation>
+    </message>
+    <message>
+        <source>Translators</source>
+        <translation>Översättare</translation>
+    </message>
+    <message>
+        <source>qBittorrent was built with the following libraries:</source>
+        <translation>qBittorrent byggdes med följande bibliotek:</translation>
+    </message>
+    <message>
+        <source>Nationality:</source>
+        <translation>Nationalitet:</translation>
+    </message>
+    <message>
+        <source>Author</source>
+        <translation>Upphovsmän</translation>
+    </message>
+</context>
+<context>
+    <name>OptionDialog</name>
+    <message>
+        <source>All addresses</source>
+        <translation>Alla adresser</translation>
+    </message>
+</context>
+<context>
+    <name>SearchJobWidget</name>
+    <message>
+        <source>Copy</source>
+        <translation>Kopiera</translation>
+    </message>
+    <message>
+        <source>Download</source>
+        <translation>Hämta</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Namn</translation>
+    </message>
+    <message>
+        <source>Description page URL</source>
+        <translation>Beskrivningssidans webbadress</translation>
+    </message>
+    <message>
+        <source>Open description page</source>
+        <translation>Öppna beskrivningssidan</translation>
+    </message>
+    <message>
+        <source>Download link</source>
+        <translation>Hämtningslänk</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
